/**
 * @file http_common.h
 * @brief Definitions common to HTTP client and server
 *
 * @section License
 *
 * Copyright (C) 2010-2019 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneTCP Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 1.9.2
 **/

#ifndef _HTTP_COMMON_H
#define _HTTP_COMMON_H

//Dependencies
#include "core/net.h"

//HTTP port number
#define HTTP_PORT 80
//HTTPS port number (HTTP over TLS)
#define HTTPS_PORT 443

//C++ guard
#ifdef __cplusplus
   extern "C" {
#endif


/**
 * @brief HTTP version numbers
 **/

typedef enum
{
   HTTP_VERSION_0_9 = 0x0009,
   HTTP_VERSION_1_0 = 0x0100,
   HTTP_VERSION_1_1 = 0x0101
} HttpVersion;


/**
 * @brief HTTP methods
 **/

typedef enum
{
   HTTP_METHOD_GET     = 0,
   HTTP_METHOD_HEAD    = 1,
   HTTP_METHOD_POST    = 2,
   HTTP_METHOD_PUT     = 3,
   HTTP_METHOD_DELETE  = 4,
   HTTP_METHOD_TRACE   = 5,
   HTTP_METHOD_CONNECT = 6,
   HTTP_METHOD_PATCH   = 7
} HttpMethod;


/**
 * @brief HTTP authentication schemes
 **/

typedef enum
{
   HTTP_AUTH_MODE_NONE   = 0,
   HTTP_AUTH_MODE_BASIC  = 1,
   HTTP_AUTH_MODE_DIGEST = 2
} HttpAuthMode;


//C++ guard
#ifdef __cplusplus
   }
#endif

#endif
